package ocsigenserver

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
API reference

API reference for Ocsigen Server. See the manual to get started.

Extensions

Requests and responses

Persistent data, writing in the logs, configuration file extension, polymorphic tables

  • Ocsigen_base.Lib This module contains some auxiliaries for the Ocsigenserver. In contrast to Ocsigen_lib_base, the function may also refer to libraries other than the standard library.
  • Ocsigen.Messages Writing messages in the logs
  • Ocsigen.Parseconfig Config file parsing. See also module Extensions.​Configuration
  • Polytables Polymorphic tables (using Map)
  • Ocsigen_base.Cache Cache. Association tables (from any kind of database) that keep the most recently used values in memory. It is also possible to set a maximum lifetime for data in the cache.
  • Ocsigen.Config Configuring Ocsigen server

Extending Ocsigen Server