package ocsigenserver

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Ocsigen_base

module Cache : sig ... end

Cache. Association tables (from any kind of database) that keep the most recently used values in memory. It is also possible to set a maximum lifetime for data in the cache.

module Config_static : sig ... end
module Lib : sig ... end

This module contains some auxiliaries for the Ocsigenserver. In contrast to Ocsigen_lib_base, the function may also refer to libraries other than the standard library.

module Loader : sig ... end

Module Loader: Dynamic loading for Ocsigen.

module Ocsigen_stream : sig ... end